==> arquillian-protocol-servlet-1.1.11.Final-sources.jar: org/jboss/arquillian/protocol/servlet/v_2_5/ProtocolDeploymentAppender.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2009, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.protocol.servlet.v_2_5;

import org.jboss.arquillian.container.test.spi.RemoteLoadableExtension;
import org.jboss.arquillian.container.test.spi.client.deployment.AuxiliaryArchiveAppender;
import org.jboss.arquillian.protocol.servlet.runner.ServletRemoteExtension;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.asset.StringAsset;
import org.jboss.shrinkwrap.api.spec.WebArchive;

/**
 * ProtocolDeploymentAppender
 * 
 * DeploymentAppender to add required resources for the protocol servlet to run  
 * in container.
 *
 * @author <a href="mailto:aslak@conduct.no">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class ProtocolDeploymentAppender implements AuxiliaryArchiveAppender
{
   @Override
   public WebArchive createAuxiliaryArchive()
   {
      // Load based on package to avoid ClassNotFoundException on HttpServlet when loading ServletTestRunner
      return ShrinkWrap.create(WebArchive.class, "arquillian-protocol.war")
                     .addPackage(ServletRemoteExtension.class.getPackage())
                     .setWebXML(new StringAsset(
                           WebUtils.createNewDescriptor().exportAsString()
                     ))
                     .addAsServiceProvider(RemoteLoadableExtension.class, ServletRemoteExtension.class);
   }
}

==> arquillian-protocol-servlet-1.9.3.Final-sources.jar: org/jboss/arquillian/protocol/servlet/v_2_5/ProtocolDeploymentAppender.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2009 Red Hat Inc. and/or its affiliates and other contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.arquillian.protocol.servlet.v_2_5;

import org.jboss.arquillian.container.test.spi.RemoteLoadableExtension;
import org.jboss.arquillian.container.test.spi.client.deployment.AuxiliaryArchiveAppender;
import org.jboss.arquillian.protocol.servlet.runner.ServletRemoteExtension;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.asset.StringAsset;
import org.jboss.shrinkwrap.api.spec.WebArchive;

/**
 * ProtocolDeploymentAppender
 * <p>
 * DeploymentAppender to add required resources for the protocol servlet to run
 * in container.
 *
 * @author <a href="mailto:aslak@conduct.no">Aslak Knutsen</a>
 * @version $Revision: $
 */
public class ProtocolDeploymentAppender implements AuxiliaryArchiveAppender {
    @Override
    public WebArchive createAuxiliaryArchive() {
        // Load based on package to avoid ClassNotFoundException on HttpServlet when loading ServletTestRunner
        return ShrinkWrap.create(WebArchive.class, "arquillian-protocol.war")
            .addPackage(ServletRemoteExtension.class.getPackage())
            .setWebXML(new StringAsset(
                WebUtils.createNewDescriptor().exportAsString()
            ))
            .addAsServiceProvider(RemoteLoadableExtension.class, ServletRemoteExtension.class);
    }
}
